@@ -1,6 +1,5 @@
 test_lambda_selection <- function() {
-  p <- rep(8, 5)
-  p[5] <- 2
+  p <- c(rep(8, 4), 2)
   inds <- matrix(c(1, 2, 3, 1, 4, 4, 4, 5), 4, 2)
   v <- list()
   for (i in 1:4) {
@@ -14,11 +13,13 @@ test_lambda_selection <- function() {
   X[[2]] <- v[[2]][, 1:2] %*% t(v[[4]][, c(1, 3)])
   X[[3]] <- v[[3]][, 1:2] %*% t(v[[4]][, 3:4])
   X[[4]] <- v[[1]][, c(1, 3)] %*% t(v[[5]][, 1:2])
-  X[[1]][matrix(runif(8*8), 8, 8) < 0.2] <- NA
-  mmpca::mmpca(X, inds, 3)
+  X[[1]][matrix(runif(8 * 8), 8, 8) < 0.2] <- NA
+  mmpca::mmpca(X, inds, 3, parallel = TRUE)
   # only checking for errors, not checking the result
   return(TRUE)
 }
-options(mc.cores=2)
+opt <- options(mc.cores = 2)
 set.seed(1)
 test_lambda_selection()
+# Reset options
+options(opt)
